@@ -1,6 +1,6 @@
 package Boot::EFI;
 
-#   $Header: /cvsroot/systemconfig/systemconfig/lib/Boot/EFI.pm,v 1.9 2003/09/23 05:40:21 dannf Exp $
+#   $Header: /cvsroot/systemconfig/systemconfig/lib/Boot/EFI.pm,v 1.10 2004/03/15 01:56:47 dannf Exp $
 
 #   Copyright (c) 2001 International Business Machines
 
@@ -56,7 +56,7 @@ use Boot;
 use Util::Log qw(:all);
 use Util::Cmd qw(:all);
 
-$VERSION = sprintf("%d.%02d", q$Revision: 1.9 $ =~ /(\d+)\.(\d+)/);
+$VERSION = sprintf("%d.%02d", q$Revision: 1.10 $ =~ /(\d+)\.(\d+)/);
 
 push @Boot::boottypes, qw(Boot::EFI);
 
@@ -78,6 +78,7 @@ sub new {
 			      /boot/efi/efi/redhat
 			      /boot/efi/efi/sgi
 			      /boot/efi/SuSE
+			      /boot/efi/efi/SuSE	
 			      );
 
     foreach my $possible (@elilo_locations) {
@@ -138,6 +139,7 @@ sub footprint_loader {
     return ((-e $$this{root} . "/boot/efi/elilo.efi" or
 	     -e $$this{root} . "/boot/efi/efi/redhat/elilo.efi" or
 	     -e $$this{root} . "/boot/efi/efi/sgi/elilo.efi" or
+	     -e $$this{root} . "/boot/efi/efi/SuSE/elilo.efi" or
 	     -e $$this{root} . "/boot/efi/SuSE/elilo.efi")
 	    and $$this{bootmenu_exe} and $$this{bootloader_exe});
 }
